==> smacof_1.5-0.tar.gz: smacof/man/smacofIndDiff.Rd <==
\name{smacofIndDiff}
\alias{smacofIndDiff}

\title{smacof for Individual Differences}
\description{Performs smacof for individual differences also known as Three-Way smacof on a list of dissimilarity matrices. Various restrictions decompositions and restrictions on the weight matrix are provided.
}

\usage{
smacofIndDiff(delta, ndim = 2, type = c("ratio", "interval", "ordinal"), 
              constraint = c("indscal", "idioscal", "identity"),
              weightmat = NULL, init = NULL, ties = "primary",  
              verbose = FALSE, modulus = 1, itmax = 1000, eps = 1e-6)

}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{delta}{A list of dissimilarity matrices or a list objects of class \code{dist}}
  \item{ndim}{Number of dimensions}
  \item{type}{MDS type}
  \item{weightmat}{Optional matrix with dissimilarity weights}
  \item{init}{Matrix with starting values for configurations (optional)}
  \item{ties}{Tie specification for non-metric MDS}
  \item{constraint}{Either \code{"indscal"}, \code{"idioscal"}, or \code{"identity"} (see details)}
  \item{verbose}{If \code{TRUE}, intermediate stress is printed out}
  \item{modulus}{Number of smacof iterations per monotone regression call}
  \item{itmax}{Maximum number of iterations}
  \item{eps}{Convergence criterion}
}
\details{If the constraint is \code{"indscal"}, INDSCAL is performed with configuration weight matrices restricted to be diagonal. IDIOSCAL can be computed using the \code{"idioscal"} argument. The weight matrices are then unconstrained. Addtional weight restrictions can be imposed with \code{"identity"} which restricts the configurations across individuals/replications/ways to be equal
}

\value{
  \item{delta}{Observed dissimilarities}
  \item{obsdiss}{List of observed dissimilarities, normalized}
  \item{confdiss}{List of configuration dissimilarities}
  \item{conf}{List of matrices of final configurations}
  \item{gspace}{Joint configurations aka group stimulus space}
  \item{cweights}{Configuration weights}
  \item{stress}{Stress-1 value}
  \item{spp}{Stress per point}
  \item{sps}{Stress per subject (matrix)}
  \item{ndim}{Number of dimensions}
  \item{model}{Type of smacof model}
  \item{niter}{Number of iterations}
  \item{nobj}{Number of objects}

}
\references{de Leeuw, J., & Mair, P. (2009). Multidimensional scaling using majorization: 
The R package smacof. Journal of Statistical Software, 31(3), 1-30, \url{http://www.jstatsoft.org/v31/i03/} 
}
\author{Jan de Leeuw and Patrick Mair}

\seealso{\code{\link{smacofConstraint}}, \code{\link{smacofSym}}, \code{\link{smacofRect}}, \code{\link{smacofSphere}}}

\examples{
data(perception)

res.id <- smacofIndDiff(perception, constraint = "identity")     ## identity restricted weights
summary(res.id)
res.id$cweights
plot(res.id)
plot(res.id, type = "p", pch = 25, col = 4, label.conf = list(label = TRUE, pos = 3, col = 4))

res.diag <- smacofIndDiff(perception, constraint = "indscal")  ## diagonally restricted weights
res.diag$cweights
plot(res.diag)
plot(res.diag, type = "p", pch = 25, col = 4, label.conf = list(label = TRUE, pos = 3, col = 4))

res.idio <- smacofIndDiff(perception, constraint = "idioscal")  ## IDIOSCAL
Wk <- res.idio$cweights
G <- res.idio$gspace
G%*%Wk[[1]]  ## configurations subject 1 (cf. res.idio$conf[[1]])
G%*%Wk[[2]]  ## configurations subject 2 (cf. res.idio$conf[[3]])


data(helm)
res.helm <- smacofIndDiff(helm, constraint = "indscal")
plot(res.helm, plot.type = "confplot")
barplot(sort(res.helm$sps, decreasing = TRUE), main = "Stress per Subject", cex.names = 0.8) 
plot(res.helm, plot.type = "bubbleplot")
plot(res.helm, plot.type = "stressplot")
plot(res.helm, plot.type = "Shepard")
plot(res.helm, plot.type = "resplot")

}

\keyword{models}

==> smacof_1.6-2.tar.gz: smacof/man/smacofIndDiff.Rd <==
\name{smacofIndDiff}
\alias{smacofIndDiff}
\alias{indscal}
\alias{idioscal}

\title{SMACOF for Individual Differences}
\description{Performs smacof for individual differences also known as Three-Way smacof on a list of dissimilarity matrices. Various restrictions decompositions and restrictions on the weight matrix are provided. The most prominent models are 
INDSCAL and IDIOSCAL.
}

\usage{
smacofIndDiff(delta, ndim = 2, type = c("ratio", "interval", "ordinal"), 
              constraint = c("indscal", "idioscal", "identity"),
              weightmat = NULL, init = NULL, ties = "primary",  
              verbose = FALSE, modulus = 1, itmax = 1000, eps = 1e-6)
              
indscal(delta, ndim = 2, type = c("ratio", "interval", "ordinal"), 
        weightmat = NULL, init = NULL, ties = "primary", 
        verbose = FALSE, modulus = 1, itmax = 1000, eps = 1e-6)

idioscal(delta, ndim = 2, type = c("ratio", "interval", "ordinal"), 
         weightmat = NULL, init = NULL, ties = "primary", 
         verbose = FALSE, modulus = 1, itmax = 1000, eps = 1e-6)

}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{delta}{A list of dissimilarity matrices or a list objects of class \code{dist}}
  \item{ndim}{Number of dimensions}
  \item{type}{MDS type}
  \item{weightmat}{Optional matrix with dissimilarity weights}
  \item{init}{Matrix with starting values for configurations (optional)}
  \item{ties}{Tie specification for non-metric MDS}
  \item{constraint}{Either \code{"indscal"}, \code{"idioscal"}, or \code{"identity"} (see details)}
  \item{verbose}{If \code{TRUE}, intermediate stress is printed out}
  \item{modulus}{Number of smacof iterations per monotone regression call}
  \item{itmax}{Maximum number of iterations}
  \item{eps}{Convergence criterion}
}
\details{If the constraint is \code{"indscal"}, INDSCAL is performed with configuration weight matrices restricted to be diagonal. \code{indscal()} is a corresponding wrapper function that can be used instead of \code{smacofIndDiff()} with 
\code{"indscal"} constraints.

IDIOSCAL can be computed using the \code{"idioscal"} argument. The weight matrices are then unconstrained. 
\code{idioscal()} is a corresponding wrapper function that can be used instead of \code{smacofIndDiff()} with 
\code{"idioscal"} constraints.

Addtional weight restrictions can be imposed with \code{"identity"} which restricts the configurations across individuals/replications/ways to be equal. 
}

\value{
  \item{delta}{Observed dissimilarities}
  \item{obsdiss}{List of observed dissimilarities, normalized}
  \item{confdiss}{List of configuration dissimilarities}
  \item{conf}{List of matrices of final configurations}
  \item{gspace}{Joint configurations aka group stimulus space}
  \item{cweights}{Configuration weights}
  \item{stress}{Stress-1 value}
  \item{spp}{Stress per point}
  \item{sps}{Stress per subject (matrix)}
  \item{ndim}{Number of dimensions}
  \item{model}{Type of smacof model}
  \item{niter}{Number of iterations}
  \item{nobj}{Number of objects}

}
\references{de Leeuw, J., & Mair, P. (2009). Multidimensional scaling using majorization: 
The R package smacof. Journal of Statistical Software, 31(3), 1-30, \url{http://www.jstatsoft.org/v31/i03/} 
}
\author{Jan de Leeuw and Patrick Mair}

\seealso{\code{\link{smacofConstraint}}, \code{\link{smacofSym}}, \code{\link{smacofRect}}, \code{\link{smacofSphere}}}

\examples{
data(perception)

res.id <- smacofIndDiff(perception, constraint = "identity")     ## identity restricted weights
summary(res.id)
res.id$cweights
plot(res.id)
plot(res.id, type = "p", pch = 25, col = 4, label.conf = list(label = TRUE, pos = 3, col = 4))

res.diag <- smacofIndDiff(perception, constraint = "indscal")  ## diagonally restricted weights
res.diag$cweights
plot(res.diag)
plot(res.diag, type = "p", pch = 25, col = 4, label.conf = list(label = TRUE, pos = 3, col = 4))

res.idio <- smacofIndDiff(perception, constraint = "idioscal")  ## IDIOSCAL
Wk <- res.idio$cweights
G <- res.idio$gspace
G%*%Wk[[1]]  ## configurations subject 1 (cf. res.idio$conf[[1]])
G%*%Wk[[2]]  ## configurations subject 2 (cf. res.idio$conf[[3]])


data(helm)
res.helm <- smacofIndDiff(helm, constraint = "indscal")
plot(res.helm, plot.type = "confplot")
barplot(sort(res.helm$sps, decreasing = TRUE), main = "Stress per Subject", cex.names = 0.8) 
plot(res.helm, plot.type = "bubbleplot")
plot(res.helm, plot.type = "stressplot")
plot(res.helm, plot.type = "Shepard")
plot(res.helm, plot.type = "resplot")

## idioscal and indscal with starting configurations:
startconf <- matrix(rnorm(20), 10, 2)
idioscal(helm, init = startconf)
indscal(helm, init = startconf)

}

\keyword{models}
